export declare type Money = {
    currencyMnemonic?: string;
    value?: number;
} & {
    [key: string]: any;
};
export declare type SimpleSearchResult = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type SearchRequest = {
    limit?: number;
    query: any;
    sorts?: Array<Sort>;
    offset?: number;
} & {
    [key: string]: any;
};
export declare type PaginatedSearchResult = {
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type ErrorResponse = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
} & {
    [key: string]: any;
};
export declare type Error = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
} & {
    [key: string]: any;
};
export declare type Variants = {
    limit: number;
    data: Array<Variant>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type ProductOption = {
    customName?: {} & {
        [key: string]: string;
    };
    defaultProductOptionValue?: string;
    description?: {} & {
        [key: string]: string;
    };
    id: string;
    image?: MediaFile;
    name?: string;
    selectedOptionValue?: string;
    shared?: boolean;
    sortingMode?: string;
    values?: Array<ProductOptionValue>;
} & {
    [key: string]: any;
};
export declare type Master = {
    masterId: string;
    orderable?: boolean;
    price?: number;
    priceMax?: number;
    prices?: {} & {
        [key: string]: number;
    };
} & {
    [key: string]: any;
};
export declare type VariantSearchResult = {
    hits: Array<Variant>;
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type VariationAttribute = {
    attributeDefinitionId: string;
    attributeDefinitionName?: {} & {
        [key: string]: string;
    };
    defaultValue?: string;
    id?: string;
    name?: {} & {
        [key: string]: string;
    };
    shared?: boolean;
    slicing?: boolean;
    values?: Array<VariationAttributeValue>;
    variationAttributeType?: string;
} & {
    [key: string]: any;
};
export declare type CatalogCategoryId = {
    catalogId: string;
    categoryId: string;
} & {
    [key: string]: any;
};
export declare type ProductType = {
    bundle?: boolean;
    bundled?: boolean;
    item?: boolean;
    master: boolean;
    option?: boolean;
    partOfProductSet?: boolean;
    partOfRetailSet?: boolean;
    retailSet?: boolean;
    set?: boolean;
    variant?: boolean;
    variationGroup?: boolean;
} & {
    [key: string]: any;
};
export declare type Variant = {
    ats?: number;
    defaultProductVariation?: boolean;
    image?: MediaFile;
    inStock?: boolean;
    online?: boolean;
    orderable?: boolean;
    price?: number;
    priceCurrency?: string;
    productId: string;
    searchable?: {} & {
        [key: string]: boolean;
    };
    variationAttributes?: Array<VariationAttribute>;
    variationValues?: {} & {
        [key: string]: string;
    };
} & {
    [key: string]: any;
};
export declare type VariationGroup = {
    orderable?: boolean;
    price?: number;
    productId: string;
    variationValues?: {} & {
        [key: string]: string;
    };
} & {
    [key: string]: any;
};
export declare type ProductOptionValue = {
    defaultProductOptionValue?: boolean;
    id: string;
    optionPrices?: Array<Money>;
    skuExtension?: string;
    value: {} & {
        [key: string]: string;
    };
} & {
    [key: string]: any;
};
export declare type VariationAttributes = {
    limit: number;
    data: Array<VariationAttribute>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type MarkupText = {
    markup: string;
    source: string;
} & {
    [key: string]: any;
};
export declare type ImageGroup = {
    images: Array<MediaFile>;
    variationAttributes?: Array<VariationAttribute>;
    viewType: string;
} & {
    [key: string]: any;
};
export declare type MediaFile = {
    absUrl?: string;
    alt?: {} & {
        [key: string]: string;
    };
    disBaseUrl?: string;
    path: string;
    title?: {} & {
        [key: string]: string;
    };
} & {
    [key: string]: any;
};
export declare type VariationAttributeValues = {
    limit: number;
    data: Array<VariationAttributeValue>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type ProductSearchResult = {
    hits: Array<Product>;
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type ProductOptions = {
    limit: number;
    data: Array<ProductOption>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type Product = {
    assignedCategories?: Array<CatalogCategoryId>;
    ats?: number;
    brand?: string;
    bundledProducts?: Array<Product>;
    creationDate?: any;
    defaultVariantId?: string;
    ean?: string;
    id: string;
    image?: MediaFile;
    imageGroups?: Array<ImageGroup>;
    inStock?: boolean;
    lastModified?: any;
    longDescription?: {} & {
        [key: string]: MarkupText;
    };
    manufacturerName?: string;
    manufacturerSku?: string;
    master?: Master;
    name?: {} & {
        [key: string]: string;
    };
    online?: boolean;
    onlineFlag?: {} & {
        [key: string]: boolean;
    };
    owningCatalogId?: string;
    owningCatalogName?: {} & {
        [key: string]: string;
    };
    pageDescription?: {} & {
        [key: string]: string;
    };
    pageKeywords?: {} & {
        [key: string]: string;
    };
    pageTitle?: {} & {
        [key: string]: string;
    };
    price?: number;
    priceCurrency?: string;
    primaryCategoryId?: string;
    productBundles?: Array<Product>;
    productOptions?: Array<ProductOption>;
    productSets?: Array<Product>;
    searchable?: {} & {
        [key: string]: boolean;
    };
    setProducts?: Array<Product>;
    shortDescription?: {} & {
        [key: string]: MarkupText;
    };
    type?: ProductType;
    unit?: string;
    upc?: string;
    variants?: Array<Variant>;
    variationAttributes?: Array<VariationAttribute>;
    variationGroups?: Array<VariationGroup>;
    variationValues?: {} & {
        [key: string]: string;
    };
} & {
    [key: string]: any;
};
export declare type VariationAttributeValue = {
    description?: {} & {
        [key: string]: string;
    };
    image?: MediaFile;
    imageSwatch?: MediaFile;
    name?: {} & {
        [key: string]: string;
    };
    orderable?: boolean;
    position?: number;
    value: string;
} & {
    [key: string]: any;
};
export declare type ProductOptionValues = {
    limit: number;
    data: Array<ProductOptionValue>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type VariationGroups = {
    limit: number;
    data: Array<VariationGroup>;
    offset: number;
    total: number;
} & {
    [key: string]: any;
};
export declare type BoolFilter = {
    filters?: Array<any>;
    operator: string;
} & {
    [key: string]: any;
};
export declare type MatchAllQuery = {} & {
    [key: string]: any;
};
export declare type FilteredQuery = {
    filter: any;
    query: any;
} & {
    [key: string]: any;
};
export declare type QueryFilter = {
    query: any;
} & {
    [key: string]: any;
};
export declare type Query = {
    boolQuery?: {
        must?: Array<any>;
        mustNot?: Array<any>;
        should?: Array<any>;
    } & {
        [key: string]: any;
    };
    filteredQuery?: {
        filter: any;
        query: any;
    } & {
        [key: string]: any;
    };
    matchAllQuery?: {} & {
        [key: string]: any;
    };
    nestedQuery?: {
        path: string;
        query: any;
        scoreMode?: string;
    } & {
        [key: string]: any;
    };
    termQuery?: {
        fields: Array<string>;
        operator: string;
        values?: Array<any>;
    } & {
        [key: string]: any;
    };
    textQuery?: {
        fields: Array<string>;
        searchPhrase: string;
    } & {
        [key: string]: any;
    };
} & {
    [key: string]: any;
};
export declare type TermQuery = {
    fields: Array<string>;
    operator: string;
    values?: Array<any>;
} & {
    [key: string]: any;
};
export declare type TermFilter = {
    field: string;
    operator: string;
    values?: Array<any>;
} & {
    [key: string]: any;
};
export declare type TextQuery = {
    fields: Array<string>;
    searchPhrase: string;
} & {
    [key: string]: any;
};
export declare type Range2Filter = {
    filterMode?: string;
    fromField: string;
    fromInclusive?: boolean;
    fromValue?: any;
    toField: string;
    toInclusive?: boolean;
    toValue?: any;
} & {
    [key: string]: any;
};
export declare type BoolQuery = {
    must?: Array<any>;
    mustNot?: Array<any>;
    should?: Array<any>;
} & {
    [key: string]: any;
};
export declare type NestedQuery = {
    path: string;
    query: any;
    scoreMode?: string;
} & {
    [key: string]: any;
};
export declare type Filter = {
    boolFilter?: {
        filters?: Array<any>;
        operator: string;
    } & {
        [key: string]: any;
    };
    queryFilter?: {
        query: any;
    } & {
        [key: string]: any;
    };
    range2Filter?: {
        filterMode?: string;
        fromField: string;
        fromInclusive?: boolean;
        fromValue?: any;
        toField: string;
        toInclusive?: boolean;
        toValue?: any;
    } & {
        [key: string]: any;
    };
    rangeFilter?: {
        field: string;
        from?: any;
        fromInclusive?: boolean;
        to?: any;
        toInclusive?: boolean;
    } & {
        [key: string]: any;
    };
    termFilter?: {
        field: string;
        operator: string;
        values?: Array<any>;
    } & {
        [key: string]: any;
    };
} & {
    [key: string]: any;
};
export declare type Sort = {
    field: string;
    sortOrder?: string;
} & {
    [key: string]: any;
};
export declare type RangeFilter = {
    field: string;
    from?: any;
    fromInclusive?: boolean;
    to?: any;
    toInclusive?: boolean;
} & {
    [key: string]: any;
};
//# sourceMappingURL=products.types.d.ts.map